@@ -127,11 +127,7 @@ strat_kmeans <- function(mraster,
   }
 
   #--- write file to disc ---#
-
-  if (!is.null(filename)) {
-    terra::writeRaster(x = kmv, filename = filename, overwrite = overwrite)
-    message("Output raster written to disc.")
-  }
+  write_raster(raster = kmv, filename = filename, overwrite = overwrite)
 
   #--- Output based on 'details' to return raster alone or list with details ---#
 
